import * as ec2 from '@aws-cdk/aws-ec2';
import * as iam from '@aws-cdk/aws-iam';
import * as cdk from '@aws-cdk/core';
import { ManagedInstanceRole } from '@renovosolutions/cdk-library-managed-instance-role';
/**
 * @stability stable
 */
export interface IInstanceServiceProps {
    /**
     * The name of the service this instance service will host.
     *
     * @stability stable
     */
    name: string;
    /**
     * The VPC to launch this service in.
     *
     * @stability stable
     */
    vpc: ec2.Vpc;
    /**
     * The subnet type to launch this service in.
     *
     * @default ec2.SubnetType.PRIVATE
     * @stability stable
     */
    subnetType?: ec2.SubnetType;
    /**
     * The Amazon Machine Image (AMI) to launch the target instance with.
     *
     * @stability stable
     */
    ami: ec2.IMachineImage;
    /**
     * Whether or not to enable logging to Cloudwatch Logs.
     *
     * @default true
     * @stability stable
     */
    enableCloudwatchLogs?: boolean;
    /**
     * Allow all outbound traffic for the instances security group.
     *
     * @default true
     * @stability stable
     */
    allowAllOutbound?: boolean;
    /**
     * Whether to disable inline ingress and egress rule optimization for the instances security group.
     *
     * If this is set to true, ingress and egress rules will not be declared under the SecurityGroup in cloudformation, but will be separate elements.
     *
     * Inlining rules is an optimization for producing smaller stack templates.
     * Sometimes this is not desirable, for example when security group access is managed via tags.
     *
     * The default value can be overriden globally by setting the context variable '@aws-cdk/aws-ec2.securityGroupDisableInlineRules'.
     *
     * @default false
     * @stability stable
     */
    disableInlineRules?: boolean;
    /**
     * Whether or not to prevent security group from containing rules that allow access to remote management ports: SSH, RDP, WinRM, WinRM over HTTPs.
     *
     * If these ports are opened when this is enabled an error will be added to CDK metadata and deployment and synth will fail.
     *
     * @default true
     * @stability stable
     */
    enableNoRemoteManagementPortsAspect?: boolean;
    /**
     * Whether or not to prevent security group from containing rules that allow access to relational DB ports: MySQL, PostgreSQL, MariaDB, Oracle, SQL Server.
     *
     * If these ports are opened when this is enabled an error will be added to CDK metadata and deployment and synth will fail.
     *
     * @default true
     * @stability stable
     */
    enableNoDBPortsAspect?: boolean;
    /**
     * Whether or not to prevent security group from containing rules that allow access from the public internet: Any rule with a source from 0.0.0.0/0 or ::/0.
     *
     * If these sources are used when this is enabled and error will be added to CDK metadata and deployment and synth will fail.
     *
     * @stability stable
     */
    enabledNoPublicIngressAspect?: boolean;
}
/**
 * @stability stable
 */
export interface IManagedLoggingPolicyProps {
    /**
     * The OS of the instance this policy is for.
     *
     * @stability stable
     */
    os: string;
}
/**
 * @stability stable
 */
export interface IAmiLookup {
    /**
     * The name string to use for AMI lookup.
     *
     * @stability stable
     */
    name: string;
    /**
     * The owners to use for AMI lookup.
     *
     * @stability stable
     */
    owners?: string[];
    /**
     * Is this AMI expected to be windows?
     *
     * @stability stable
     */
    windows?: boolean;
}
export declare function ec2ImageToOsString(stack: cdk.Construct, image: ec2.IMachineImage): string;
/**
 * @stability stable
 */
export declare class ManagedLoggingPolicy extends cdk.Construct {
    /**
     * @stability stable
     */
    readonly policy: iam.ManagedPolicy;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: IManagedLoggingPolicyProps);
}
/**
 * @stability stable
 */
export declare class InstanceService extends cdk.Construct {
    /**
     * @stability stable
     */
    readonly instanceProfile: ManagedInstanceRole;
    /**
     * @stability stable
     */
    readonly securityGroup: ec2.SecurityGroup;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: IInstanceServiceProps);
}
